@@ -1,6 +1,6 @@
 package Mail::GPG;
 
-$VERSION = "1.0.9";
+$VERSION = "1.0.10";
 
 use strict;
 use Carp;
@@ -501,7 +501,8 @@ sub _parse_key_list {
 
           #-- tell Perl that this variable is utf8 encoded
           #-- (if Perl version is 5.8.0 or greater)
-          Encode::_utf8_on($_) if $] >= 5.008;
+          eval { $_ = Encode::decode("utf-8", $_, Encode::FB_CROAK) }
+            if $] >= 5.008;
         }
 
         @ids = List::MoreUtils::uniq @ids;
